import { createHmac } from 'node:crypto';
import { existsSync } from 'node:fs';
import { readFile } from 'node:fs/promises';
import { resolve } from 'node:path';
import { pusherConfig } from './configuration.js';
function pageExists(server, page) {
    return existsSync(resolve(server.rootDir, `${page}.html`));
}
export function pusherAuthHandler(request, reply) {
    const { key, secret } = pusherConfig;
    const { socket_id: socket, channel_name: channel } = request.body;
    const user = JSON.stringify({
        id: 'freya-slides-sync-guest'
    });
    const stringToSign = `${socket}:${channel}`;
    const signature = createHmac('sha256', secret).update(stringToSign).digest().toString('hex');
    // eslint-disable-next-line @typescript-eslint/no-floating-promises
    reply.send({
        auth: `${key}:${signature}`,
        user_data: user
    });
}
export async function talkHandler(request, reply) {
    const talk = request.params.talk;
    if (talk === '404.html' || talk === '__status.html' || !pageExists(this, talk)) {
        return reply.code(404).sendFile('404.html');
    }
    if (request.query.export === 'true') {
        const page = await readFile(resolve(this.rootDir, `${talk}.html`), 'utf-8');
        // page = singleSlide(page, parseInt(request.params.slide, 10))
        return reply.type('text/html').send(page);
    }
    return reply.sendFile(`${talk}.html`);
}
export function assetsHandler(request, reply) {
    const talk = request.params.talk;
    if (talk === '404.html' || talk === '__status.html' || !pageExists(this, talk)) {
        // eslint-disable-next-line @typescript-eslint/no-floating-promises
        reply.code(404).sendFile('404.html');
        return;
    }
    void reply.sendFile(`${talk}_assets.html`);
}
export function setupServer(server, isProduction) {
    if (pusherConfig) {
        server.route({
            method: 'POST',
            url: '/pusher/auth',
            handler: pusherAuthHandler
        });
    }
    server.route({
        method: 'GET',
        url: '/',
        handler (_, reply) {
            // eslint-disable-next-line @typescript-eslint/no-floating-promises
            reply.sendFile('index.html');
        }
    });
    server.route({
        method: 'GET',
        url: '/sw.js',
        handler (_, reply) {
            // eslint-disable-next-line @typescript-eslint/no-floating-promises
            reply.sendFile('sw.js');
        }
    });
    server.route({
        method: 'GET',
        url: '/:talk',
        handler: talkHandler
    });
    if (!isProduction) {
        server.route({
            method: 'GET',
            url: '/:talk/assets',
            handler: assetsHandler
        });
    }
    server.route({
        method: 'GET',
        url: '/:talk/:slide(^\\d+)',
        handler: talkHandler
    });
    return {
        directory: 'html'
    };
}
