import { jsx as _jsx, jsxs as _jsxs, Fragment as _Fragment } from "react/jsx-runtime";
import { danteDir, serializeCSSClasses } from 'dante';
import { readFile } from 'node:fs/promises';
import { resolve } from 'node:path';
import { fileURLToPath } from 'node:url';
import { Fragment } from 'react';
import { finalizeJs } from '../slidesets/generators.js';
export function body({ context, talks }) {
    const resolveClasses = context.extensions.freya.resolveClasses;
    const allTalks = Object.entries(talks);
    const currentTalks = allTalks.filter(([, talk])=>!talk.document.archived);
    const archivedTalks = allTalks.filter(([, talk])=>talk.document.archived);
    return /*#__PURE__*/ _jsxs("main", {
        className: resolveClasses('freya@index'),
        children: [
            currentTalks.length > 0 && /*#__PURE__*/ _jsxs(_Fragment, {
                children: [
                    /*#__PURE__*/ _jsx("h1", {
                        className: resolveClasses('freya@index__header'),
                        children: "Current Slidesets"
                    }),
                    currentTalks.map(([id, talk])=>/*#__PURE__*/ _jsxs(Fragment, {
                            children: [
                                /*#__PURE__*/ _jsx("a", {
                                    href: `/${id}`,
                                    className: resolveClasses('freya@index__talk'),
                                    children: talk.document.title
                                }),
                                /*#__PURE__*/ _jsx("h4", {
                                    className: resolveClasses('freya@index__talk__author'),
                                    children: talk.document.author.name
                                })
                            ]
                        }, `talk:${id}`))
                ]
            }),
            archivedTalks.length > 0 && /*#__PURE__*/ _jsxs(_Fragment, {
                children: [
                    /*#__PURE__*/ _jsx("h1", {
                        className: resolveClasses('freya@index__header', 'freya@index__header--next'),
                        children: "Archived Slidesets"
                    }),
                    archivedTalks.map(([id, talk])=>/*#__PURE__*/ _jsxs(Fragment, {
                            children: [
                                /*#__PURE__*/ _jsx("a", {
                                    href: `/${id}`,
                                    className: resolveClasses('freya@index__talk'),
                                    children: talk.document.title
                                }),
                                /*#__PURE__*/ _jsx("h4", {
                                    className: resolveClasses('freya@index__talk__author'),
                                    children: talk.document.author.name
                                })
                            ]
                        }, `talk:${id}`))
                ]
            })
        ]
    });
}
export async function page(context, bodyClassName) {
    const siteVersion = `globalThis.__freyaSiteVersion = "${context.version}"`;
    const hotReload = !context.isProduction ? await readFile(resolve(danteDir, 'dist/assets/hot-reload.js'), 'utf8') : '';
    const serviceWorker = context.isProduction ? await readFile(fileURLToPath(new URL('../assets/js/service-worker.js', import.meta.url)), 'utf8') : '';
    const js = await finalizeJs([
        siteVersion,
        hotReload,
        serviceWorker
    ].join('\n;\n'));
    return /*#__PURE__*/ _jsxs("html", {
        lang: "en",
        children: [
            /*#__PURE__*/ _jsxs("head", {
                children: [
                    /*#__PURE__*/ _jsx("meta", {
                        charSet: "utf-8"
                    }),
                    /*#__PURE__*/ _jsx("meta", {
                        name: "viewport",
                        content: "width=device-width, initial-scale=1"
                    }),
                    /*#__PURE__*/ _jsx("title", {
                        children: "Slidesets"
                    }),
                    /*#__PURE__*/ _jsx("link", {
                        rel: "preload",
                        as: "font",
                        crossOrigin: "anonymous",
                        href: "https://fonts.gstatic.com/s/varelaround/v20/w8gdH283Tvk__Lua32TysjIfp8uPLdshZg.woff2"
                    }),
                    /*#__PURE__*/ _jsx("script", {
                        defer: true,
                        type: "text/javascript",
                        dangerouslySetInnerHTML: {
                            __html: js
                        }
                    }),
                    /*#__PURE__*/ _jsx("style", {
                        ...serializeCSSClasses(context)
                    })
                ]
            }),
            /*#__PURE__*/ _jsx("body", {
                className: bodyClassName,
                children: "@BODY@"
            })
        ]
    });
}
